/**
 * ==============================================
 *  DQL Adapter for SimQPN
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Simon Eismann, Juergen Walter and other contributors.
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.dql.connector.simqpn.tests;

import static org.junit.Assert.*;

import java.util.Arrays;
import java.util.Collection;

import org.dom4j.Element;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;
import org.junit.runners.Parameterized.Parameter;
import org.junit.runners.Parameterized.Parameters;

import tools.descartes.dql.connector.simqpn.tests.util.TestUtil;
import tools.descartes.dql.connector.simqpn.util.FileUtil;

/*
 * This test checks if the model is correctly imported as a Element
 * To do this it loads the xml as a Element and compares the Element's
 * .toXML.toString() to the actual content of the file
 */

@RunWith(Parameterized.class)
public class NetUtilTest {
    @Parameters
    public static Collection<Object[]> data() {
        return Arrays.asList(new Object[][] {     
                 { "ispass03.qpe" }, 
                 { "SPECjms2007Model.qpe" } 
           });
    }

    @Parameter
    public String path;
    
	@Test
	public void test() {
		String modelPath = FileUtil.getPath(path);
		
		Element net = FileUtil.loadXmlFromFile(modelPath);       
		String result = net.asXML().toString();
		
		assertTrue(TestUtil.contentCompare(prepareString(TestUtil.loadFromFile(modelPath)), result));
	}
	
	private String prepareString(String xml) {
		return xml.substring(xml.indexOf("<net"));
	}
}
