/**
 * ==============================================
 *  DQL Adapter for SimQPN
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Simon Eismann, Juergen Walter and other contributors.
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.dql.connector.simqpn.tests;

import static org.junit.Assert.assertEquals;

import java.util.Arrays;
import java.util.Collection;
import java.util.Properties;

import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;
import org.junit.runners.Parameterized.Parameter;
import org.junit.runners.Parameterized.Parameters;

import tools.descartes.dql.connector.simqpn.ModelStructureQueryConnectorImpl;
import tools.descartes.dql.connector.simqpn.PerformanceMetricsQueryConnectorImpl;
import tools.descartes.dql.connector.simqpn.tests.util.TestUtil;
import tools.descartes.dql.connector.simqpn.util.EntityMappingUtil;
import tools.descartes.dql.connector.simqpn.util.FileUtil;
import tools.descartes.dql.models.mapping.domain.DoF;
import tools.descartes.dql.models.mapping.mapping.EntityMapping;
import tools.descartes.dql.models.mapping.mapping.MappingFactory;
import tools.descartes.dql.models.mapping.mapping.impl.MappingFactoryImpl;

@RunWith(Parameterized.class)
public class XMLModificationForDofTest {
    @Parameters
    public static Collection<Object[]> data() {
        return Arrays.asList(new Object[][] {     
        		{"expectedModifiedXML1.qpe", "ispass03.qpe", "WLS-Thread-Pool_t", 3},
           });
    }
    
    @Parameter(value = 0)
	public String resultName;
	@Parameter(value = 1)
	public String modelName;
	@Parameter(value = 2)
	public String dofIdentifier;
	@Parameter(value = 3)
	public int dofValue;
	
	@Test
	public void xmlModificationForDofTest() {
		PerformanceMetricsQueryConnectorImpl pmqc = new PerformanceMetricsQueryConnectorImpl();
		EntityMapping query = createQuery(dofIdentifier, dofValue);
		TestUtil.addDefaultResultType(query);
		EntityMapping result = pmqc.requestDoFMetrics(query).get(0);
		String modifiedXML = removeChangingIds(TestUtil.loadFromFile(result.getDoFModelLocation()));
		String expectedXML = removeChangingIds(TestUtil.loadFromFile(FileUtil.getPath(resultName)));

		if (!TestUtil.contentCompare(expectedXML, modifiedXML))
			assertEquals(expectedXML, modifiedXML);
	}
		
	private String removeChangingIds(String s) {
		return s.replaceAll("event-manager-id=\"_[0-9]*\"", "")
				.replaceAll("DQLConfiguration\" id=\"_[0-9]*\"", "");
	}
	
	private  EntityMapping createQuery(String dofName, int dofValue) {
		MappingFactory mappingFactory = MappingFactoryImpl.init();
		EntityMapping entity = mappingFactory.createEntityMapping();
		entity.setModelLocation(FileUtil.getPath(modelName));
		
		ModelStructureQueryConnectorImpl msqc = new ModelStructureQueryConnectorImpl();
		entity = msqc.requestEntities(entity);
		entity = msqc.requestProbes(entity);
		DoF dof = EntityMappingUtil.createDof("test", -1);
		dof.setProperties(new Properties());
		dof.getProperties().setProperty("value", "" + dofValue);
		dof.setIdentifier(dofName);
		entity.getDoF().add(dof);
	return entity;
	}


}
