/**
 * ==============================================
 *  DQL Adapter for SimQPN
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Simon Eismann, Juergen Walter and other contributors.
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.dql.connector.simqpn.configuration;

import org.dom4j.Element;
import org.dom4j.Node;

public class IdManager {
	private static final String leadingString = "_";
	private long highestId;
	
	public IdManager(Element net) {
		highestId = findHighestId(net);
	}
	
	public String getNextId() {
		highestId++;
		return leadingString + highestId;
	}
	
    private long findHighestId(Element element) {
    	long highestId = 0;
        for ( int i = 0, size = element.nodeCount(); i < size; i++ ) {
            Node node = element.node(i);
            if ( node instanceof Element ) {
            	Element el = (Element) node;
            	if (el.attributeValue("id") != null) {
            		if (el.attributeValue("id").substring(1).matches("[0-9]+")) {
	            		long id = Long.parseLong(el.attributeValue("id").substring(1));
	            		if (id > highestId)
	            			highestId = id;
            		}
            	}
            	long id = findHighestId( (Element) node );
        		if (id > highestId)
        			highestId = id;
            }
        }
        return highestId;
    }
}