/**
 * ==============================================
 *  DQL Adapter for SimQPN
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Simon Eismann, Juergen Walter and other contributors.
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.dql.connector.simqpn.metrics;

import javax.xml.xpath.XPath;
import javax.xml.xpath.XPathExpression;
import javax.xml.xpath.XPathFactory;

import org.w3c.dom.Document;

import tools.descartes.dql.connector.simqpn.util.NetUtil;
import tools.descartes.dql.connector.simqpn.util.PerformanceMetricsUtil;

public class PerformanceMetric {
	private Metric simQPNMetric;
	private int statLevel;
	private String colorName;
	private boolean queueName;
	private boolean depository;

	public PerformanceMetric(Metric simQPNMetric, int statLevel, String colorName, boolean queueName, boolean depository) {
		this.simQPNMetric = simQPNMetric;
		this.statLevel = statLevel;
		this.colorName = colorName;
		this.queueName = queueName;
		this.depository = depository;
	}
	
	public PerformanceMetric(Metric simQPNMetric, int statLevel, String colorName, boolean queueName) {
		this.simQPNMetric = simQPNMetric;
		this.statLevel = statLevel;
		this.colorName = colorName;
		this.queueName = queueName;
		this.depository = false;
	}
	
	public void setColorName(String colorName) {
		this.colorName = colorName;
	}
	
	public boolean isDepository() {
		return depository;
	}
	
	public boolean hasColor() {
		return (colorName != null);
	}
	
	public boolean hasQueue() {
		return queueName;
	}
	
	public String getColorName() {
		return colorName;
	}
	
	public String getDQLName() {
		String ret = "";
		if (isDepository())
			ret += "Depository_";
		if (hasColor())
			ret += colorName + "_";
		ret += PerformanceMetricsUtil.getDQLNameForMetric(simQPNMetric);
		return ret;
	}

	public int getStatLevel() {
		return statLevel;
	}
	
	public String toString() {
		return getDQLName();
	}
	
	public Double getValue(Document d, String placeName, String placeType) {
		try {
		XPathFactory xPathfactory = XPathFactory.newInstance();
		XPath xpath = xPathfactory.newXPath();
		XPathExpression expr = xpath.compile(getXpath(placeName, placeType));
		String s = expr.evaluate(d);
		return Double.valueOf(s);
		} catch (Exception e) {
			//TODO
			return null;
		}
	}
	
	private String getXpath(String placeName, String placeType) {
		if (placeType.equals("queue"))
			return getQueueXpath(NetUtil.removeQueueTag(placeName));
		if (placeType.equals("ordinary-place"))
			placeType = "place";
		else if (isDepository())
			placeType = "qplace:depository";
		else if (placeType.equals("probe"))
				placeType = "probe";
		else
			placeType = "qplace:queue";
		String colorString = "";
		if (hasColor())
			colorString = "/color[@name='" + colorName + "']";
		return "/simqpn-results/observed-element[@name='" + placeName + "' and @type='" 
				+ placeType + "']" + colorString 
				+ "/metric[@type='" + simQPNMetric.getType() + "']/@value";
	}

	private String getQueueXpath(String placeName) {
		String ret = "/simqpn-results/observed-element[@name='" + placeName + "' and @type='queue']/";
		ret += "metric[@type='" + simQPNMetric.getType() + "']/@value";
		return ret;
	}

	public boolean equals(Object o) {
		if (!(o instanceof PerformanceMetric))
			return false;
		return this.getDQLName().equals(((PerformanceMetric) o).getDQLName());
	}
	
	public int hashCode() {
		return 0;
	}
}
