/**
 * ==============================================
 *  DQL Adapter for SimQPN
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Simon Eismann, Juergen Walter and other contributors.
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.dql.connector.simqpn.progress;

import java.util.LinkedList;
import java.util.List;

import tools.descartes.dql.connector.QueryProgressListener;

public class DQLListenerNotifier {
	private List<QueryProgressListener> listeners = 
			new LinkedList<QueryProgressListener>();
	private int numberOfRuns;
	private int currentRun;

	public DQLListenerNotifier() {
		this.numberOfRuns = 1;
		this.currentRun = 0;
	}
	
	// the 2 seconds per run are used as a buffer to make things look better for simulations 
	// with runtime of 0. Could also be seen as an estimate for time spend inside connector 
	// routines
	public void updateRemainingTime(int seconds, int totalTimeInSeconds) {
		seconds += (numberOfRuns - currentRun) * totalTimeInSeconds;
		seconds += 2 * (numberOfRuns - currentRun);
		for (QueryProgressListener l: listeners)
			l.updateRemainingTime(seconds);
	}
	
	public void updateSubtask(String subtaskName) {
		if (numberOfRuns != 1)
			subtaskName = "Simulation " + currentRun + "/" + numberOfRuns 
					+ ": " + subtaskName;
		for (QueryProgressListener l: listeners)
			l.updateSubTask(subtaskName);;
	}
	
	public void updateQueryProgress(float percent) {
		percent = percent / numberOfRuns + (currentRun - 1) * 100 / numberOfRuns; 
		for (QueryProgressListener l: listeners)
			l.updateProgress(percent);
	}
	
	public void addListener(QueryProgressListener listener) {
		listeners.add(listener);
	}
	
	public void updateNextRunStarted() {
		if (currentRun >= numberOfRuns)
			throw new IllegalStateException("Internal error");
		currentRun++;
	}
	
	public void setNumberOfRuns(int numberOfRuns) {
		if (currentRun != 0)
			throw new IllegalStateException("Internal error");
		this.numberOfRuns = numberOfRuns;
	}
}
