/**
 * ==============================================
 *  DQL Adapter for SimQPN
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Simon Eismann, Juergen Walter and other contributors.
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.dql.connector.simqpn.progress;

import de.tud.cs.simqpn.kernel.SimQPNConfiguration;
import de.tud.cs.simqpn.kernel.monitor.SimulatorProgress;

public class SimQPNProgressListener implements SimulatorProgress{

	private DQLListenerNotifier notifier;
	private int totalTime;
	
	public SimQPNProgressListener(DQLListenerNotifier notifier) {
		this.notifier = notifier;
	}
	
	@Override
	public void finishWarmUp(int arg0, SimQPNConfiguration config) {
		notifier.updateSubtask("Simulating Steady-State");
	}
	
	@Override
	public void startSimulation(SimQPNConfiguration config) {
		notifier.updateSubtask("Warmup-Period");
	}

	@Override
	public double getMaxUpdateLogicalTimeInterval(SimQPNConfiguration configuration) {
		return configuration.totRunLength / 20.0;
	}

	@Override
	public long getMaxUpdateRealTimeInterval() {
		return 30000; // 30 sec
	}

	@Override
	public void updateSimulationProgress(int lpID, double progress, long elapsedTime,
			SimQPNConfiguration configuration, boolean inWarmup) {
		totalTime += elapsedTime;
		notifier.updateRemainingTime((int) ((totalTime / progress) * (100.0 - progress) / 1000),
				(int)(totalTime/progress * 100)/1000);
		notifier.updateQueryProgress((float)progress);
	}
	
	@Override
	public void finishSimulation() {}

	@Override
	public void finishSimulationRun() {}

	@Override
	public boolean isCanceled() { return false; }

	@Override
	public void warning(int arg0, String arg1) {}

	@Override
	public void precisionCheck(int arg0, boolean arg1, String arg2) {}

	@Override
	public void startSimulationRun(int arg0, SimQPNConfiguration arg1) {}

}
