/**
 * ==============================================
 *  DQL Adapter for SimQPN
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Simon Eismann, Juergen Walter and other contributors.
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.dql.connector.simqpn.util;

import java.math.BigDecimal;
import java.util.LinkedList;
import java.util.List;

import tools.descartes.dql.models.mapping.domain.DecimalResult;
import tools.descartes.dql.models.mapping.domain.DoF;
import tools.descartes.dql.models.mapping.domain.DomainFactory;
import tools.descartes.dql.models.mapping.domain.Entity;
import tools.descartes.dql.models.mapping.domain.Probe;

public class EntityMappingUtil {

	public static Entity createEntity(String name) {
		final Entity service = DomainFactory.eINSTANCE.createEntity();
		service.setIdentifier(name);
		service.setAlias(name);
		return service;
	}
	
	public static DecimalResult createDecimalResult(String metricName, Double value, double accuracy) {
		return createDecimalResult(metricName, value, accuracy, true);
	}
	
	public static DecimalResult createDoFParameter(String parameterName, Double value) {
		final DecimalResult result = DomainFactory.eINSTANCE.createDecimalResult();
		result.setValid(true);
		result.setValue(BigDecimal.valueOf(value));
		return result;
	}
	
	public static DecimalResult createDecimalResult(String metricName, Double value, double accuracy, boolean valid) {
		final DecimalResult result = DomainFactory.eINSTANCE.createDecimalResult();
		result.setValid(valid);
		try {
		result.setValue(BigDecimal.valueOf(value));
		} catch (Exception e) {
			System.out.println();
		}
		return result;
	}
	
	public static Probe createProbe(String name) {
		Probe p = DomainFactory.eINSTANCE.createProbe();
		p.setMetricName(name);
		return p;
	}
	
	public static List<Entity> createEntity(List<String> resourceNames) {
		List<Entity> resources = new LinkedList<Entity>();
		for (String resourceName: resourceNames)
			resources.add(createEntity(resourceName));
		return resources;
	}

	public static DoF createDof(String dofName, int initialValue) {
		DoF dof = DomainFactory.eINSTANCE.createDoF();
		dof.setIdentifier(dofName);
		dof.setAlias(dofName);
		dof.setCurrentState(String.valueOf(initialValue));
		return dof;
	}
}
